ramonak.stemmer package
=======================

Submodules
----------

ramonak.stemmer.base module
---------------------------

.. automodule:: ramonak.stemmer.base
   :members:
   :undoc-members:
   :show-inheritance:

ramonak.stemmer.flexistat module
--------------------------------

.. automodule:: ramonak.stemmer.flexistat
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ramonak.stemmer
   :members:
   :undoc-members:
   :show-inheritance:
